@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.011-10-g7b43191
+package Dist::Zilla::Plugin::VerifyPhases; # git description: v0.012-4-g2421602
 # ABSTRACT: Compare data and files at different phases of the distribution build process
 # KEYWORDS: plugin distribution configuration phase verification validation
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Moose;
 with
@@ -72,7 +72,7 @@ sub BUILD
     %zilla_constructor_args = map {
         my $attr = $meta->find_attribute_by_name($_);
         $attr && $attr->has_value($zilla) ? ( $_ => $attr->get_value($zilla) ) : ()
-    } qw(name version release_status abstract main_module authors distmeta _license_class _copyright_holder _copyright_year),
+    } qw(name version release_status abstract main_module authors distmeta _license_class _copyright_holder _copyright_year);
 }
 
 # no reason to include configs - this plugin does not alter the build output
@@ -311,8 +311,8 @@ sub after_build
     delete $new_distmeta->{prereqs};
     foreach my $ignore_key ($self->skip_distmeta)
     {
-        $new_distmeta->{$ignore_key} = Test::Deep::ignore;
-        delete $new_distmeta->{$ignore_key} if not exists $distmeta->{$ignore_key};
+        $distmeta->{$ignore_key} = Test::Deep::ignore;
+        delete $distmeta->{$ignore_key} if not exists $new_distmeta->{$ignore_key};
     }
     my ($ok, $stack) = cmp_details($new_distmeta, $distmeta);
     if (not $ok)
@@ -342,7 +342,7 @@ Dist::Zilla::Plugin::VerifyPhases - Compare data and files at different phases o
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
